@@ -25,15 +25,14 @@ class Processor(object):
         if resp:
             data = resp
 
-        if 'sentry.interfaces.Stacktrace' in data:
-            self.filter_stacktrace(data['sentry.interfaces.Stacktrace'])
+        if 'exception' in data:
+            if 'values' in data['exception']:
+                for value in data['exception'].get('values', []):
+                    if 'stacktrace' in value:
+                        self.filter_stacktrace(value['stacktrace'])
 
-        if 'sentry.interfaces.Exception' in data:
-            if 'stacktrace' in data['sentry.interfaces.Exception']:
-                self.filter_stacktrace(data['sentry.interfaces.Exception']['stacktrace'])
-
-        if 'sentry.interfaces.Http' in data:
-            self.filter_http(data['sentry.interfaces.Http'])
+        if 'request' in data:
+            self.filter_http(data['request'])
 
         return data
 
@@ -90,9 +89,7 @@ class SanitizePasswordsProcessor(Processor):
         return value
 
     def filter_stacktrace(self, data):
-        if 'frames' not in data:
-            return
-        for frame in data['frames']:
+        for frame in data.get('frames', []):
             if 'vars' not in frame:
                 continue
             frame['vars'] = varmap(self.sanitize, frame['vars'])
