@@ -9,10 +9,11 @@ from __future__ import absolute_import
 
 import atexit
 import logging
-import time
 import threading
 import os
 
+from time import sleep, time
+
 from raven.transport.base import AsyncTransport
 from raven.transport.http import HTTPTransport
 from raven.utils.compat import Queue
@@ -35,16 +36,67 @@ class AsyncWorker(object):
         self.start()
 
     def main_thread_terminated(self):
-        size = self._queue.qsize()
-        if size:
+        self._lock.acquire()
+        try:
+            if not self._thread:
+                # thread not started or already stopped - nothing to do
+                return
+
+            # wake the processing thread up
+            self._queue.put_nowait(self._terminator)
+
             timeout = self.options['shutdown_timeout']
-            print("Sentry is attempting to send %s pending error messages" % size)
-            print("Waiting up to %s seconds" % timeout)
-            if os.name == 'nt':
-                print("Press Ctrl-Break to quit")
-            else:
-                print("Press Ctrl-C to quit")
-            self.stop(timeout=timeout)
+
+            # wait briefly, initially
+            initial_timeout = 0.1
+            if timeout < initial_timeout:
+                initial_timeout = timeout
+
+            if not self._timed_queue_join(initial_timeout):
+                # if that didn't work, wait a bit longer
+                # NB that size is an approximation, because other threads may
+                # add or remove items
+                size = self._queue.qsize()
+
+                print("Sentry is attempting to send %i pending error messages"
+                      % size)
+                print("Waiting up to %s seconds" % timeout)
+
+                if os.name == 'nt':
+                    print("Press Ctrl-Break to quit")
+                else:
+                    print("Press Ctrl-C to quit")
+
+                self._timed_queue_join(timeout - initial_timeout)
+
+            self._thread = None
+
+        finally:
+            self._lock.release()
+
+    def _timed_queue_join(self, timeout):
+        """
+        implementation of Queue.join which takes a 'timeout' argument
+
+        returns true on success, false on timeout
+        """
+        deadline = time() + timeout
+        queue = self._queue
+
+        queue.all_tasks_done.acquire()
+        try:
+            while queue.unfinished_tasks:
+                delay = deadline - time()
+                if delay <= 0:
+                    # timed out
+                    return False
+
+                queue.all_tasks_done.wait(timeout=delay)
+
+            return True
+
+        finally:
+            queue.all_tasks_done.release()
 
     def start(self):
         """
@@ -77,17 +129,20 @@ class AsyncWorker(object):
         self._queue.put_nowait((callback, args, kwargs))
 
     def _target(self):
-        while 1:
+        while True:
             record = self._queue.get()
-            if record is self._terminator:
-                break
-            callback, args, kwargs = record
             try:
-                callback(*args, **kwargs)
-            except Exception:
-                logger.error('Failed processing job', exc_info=True)
+                if record is self._terminator:
+                    break
+                callback, args, kwargs = record
+                try:
+                    callback(*args, **kwargs)
+                except Exception:
+                    logger.error('Failed processing job', exc_info=True)
+            finally:
+                self._queue.task_done()
 
-            time.sleep(0)
+            sleep(0)
 
 
 class ThreadedHTTPTransport(AsyncTransport, HTTPTransport):
